@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: hashable
-version: 1.1.2.2
-id: hashable-1.1.2.2-6a4ed2e9867bca45698894dcbd97c792
+version: 1.1.2.3
+id: hashable-1.1.2.3-d030b9fe5b35dcb16975530055dde91a
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: johan.tibell@gmail.com
 stability: Provisional
 homepage: http://github.com/tibbe/hashable
 package-url:
+synopsis: A class for types that can be converted to a hash value
 description: This package defines a class, '\''Hashable'\'', for types that
              can be converted to a hash value.  This class
              exists for the benefit of hashing-based data
@@ -21,22 +22,23 @@ pkgpath: devel/hs-hashable
 exposed: True
 exposed-modules: Data.Hashable
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/hashable-1.1.2.2
-library-dirs: /usr/local/lib/ghc/hashable-1.1.2.2
-hs-libraries: HShashable-1.1.2.2
+trusted: False
+import-dirs: /usr/local/lib/ghc/hashable-1.1.2.3
+library-dirs: /usr/local/lib/ghc/hashable-1.1.2.3
+hs-libraries: HShashable-1.1.2.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         ghc-prim-0.2.0.0-d9df11f804556f362beb0ea4e67261ba
-         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
+         ghc-prim-0.2.0.0-7d3c2c69a5e8257a04b2c679c40e2fa7
+         text-0.11.2.3-0a507fb72e97feed1b44644051bc0e5f
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hashable-1.1.2.2/html/hashable.haddock
-haddock-html: /usr/local/share/doc/hs-hashable-1.1.2.2/html
+haddock-interfaces: /usr/local/share/doc/hs-hashable-1.1.2.3/html/hashable.haddock
+haddock-html: /usr/local/share/doc/hs-hashable-1.1.2.3/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
